@@ -33,11 +33,11 @@ class Verilator(Edatool):
         # run_options?
     }
 
-    def configure(self, edam):
-        super().configure(edam)
+    def setup(self, edam):
+        super().setup(edam)
 
         # Future improvement: Separate include directories of c and verilog files
-        incdirs = set()
+        incdirs = []
 
         verilator_file = self.name + ".vc"
 
@@ -56,17 +56,13 @@ class Verilator(Edatool):
 
         vc += self.tool_options.get("verilator_options", [])
 
-        for include_dir in incdirs:
-            vc.append(f"+incdir+" + include_dir)
-            vc.append("-CFLAGS -I" + include_dir)
-
         vlt_files = []
         vlog_files = []
         opt_c_files = []
         uhdm_files = []
 
         unused_files = []
-        depfiles = []
+        depfiles = [verilator_file]
         for f in self.files:
             file_type = f.get("file_type", "")
             depfile = True
@@ -96,6 +92,10 @@ class Verilator(Edatool):
         if uhdm_files:
             vc.append("--uhdm-ast-sv")
 
+        for include_dir in incdirs:
+            vc.append(f"+incdir+" + include_dir)
+            vc.append("-CFLAGS -I" + include_dir)
+
         vc += vlt_files + uhdm_files + vlog_files
 
         vc.append(f"--top-module {self.toplevel}\n")
@@ -111,8 +111,7 @@ class Verilator(Edatool):
         for k, v in self.vlogdefine.items():
             vc.append("-D{}={}\n".format(k, self._param_value_str(v)))
 
-        with open(os.path.join(self.work_root, verilator_file), "w") as ffile:
-            ffile.write("\n".join(vc) + "\n")
+        self.vc = vc
 
         mk_file = f"V{self.toplevel}.mk"
         exe_file = f"V{self.toplevel}"
@@ -124,18 +123,21 @@ class Verilator(Edatool):
         )
 
         if mode == "lint-only":
-            self.default_target = mk_file
+            commands.set_default_target(mk_file)
         else:
             commands.add(
                 ["make", "-f", mk_file] + self.tool_options.get("make_options", []),
                 [exe_file],
                 [mk_file],
             )
-            self.default_target = exe_file
+            commands.set_default_target(exe_file)
 
-        self.commands = commands.commands
+        self.commands = commands
 
-    def run(self, args):
+    def write_config_files(self):
+        self.update_config_file(self.name + ".vc", "\n".join(self.vc) + "\n")
+
+    def run(self):
         self.args = []
         for key, value in self.plusarg.items():
             self.args += ["+{}={}".format(key, self._param_value_str(value))]
